@@ -1,5 +1,5 @@
 "parlap" <-
-function(lmom,checklmom=TRUE) {
+function(lmom,checklmom=TRUE,...) {
 
     para <- vector(mode="numeric", length=2)
     names(para) <- c("xi","alpha")
